<?php
/**
 * Loads the child theme textdomain.
 */
function fort_grid_load_language() {
    load_child_theme_textdomain( 'fort-masonry' );
}
add_action( 'after_setup_theme', 'fort_grid_load_language' );

if ( ! defined( 'FORT_MASONRY_S_VERSION' ) ) {
    // Replace the version number of the theme on each release.
    define( 'FORT_MASONRY_S_VERSION', '1.0.0' );
}


/**
* Enqueue Style of Fort Grid
*/
add_action( 'wp_enqueue_scripts', 'fort_grid_style');
function fort_grid_style() {
	wp_enqueue_style( 'fort-style', get_template_directory_uri() . '/style.css' );
	wp_enqueue_style( 'fort-masonry-style', get_stylesheet_directory_uri() . '/style.css', array('fort-style'));
}

/**
 * Enqueue scripts and styles.
 */
function fort_grid_scripts(){

    global $fort_theme_options;
    if (!empty($fort_theme_options['fort-pagination-options'])) {
		$fort_pagination_option = $fort_theme_options['fort-pagination-options'];
		if (($fort_pagination_option == 'ajax') ) {
			wp_enqueue_script('fort-custom-pagination', get_stylesheet_directory_uri() . '/candidthemes/assets/custom-infinte-pagination.js', array('jquery'), _S_VERSION, true);
			global $wp_query;
			$paged = (get_query_var('paged') > 1) ? get_query_var('paged') : 1;
			$max_num_pages = $wp_query->max_num_pages;

			wp_localize_script('fort-custom-pagination', 'fort_ajax', array(
				'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
				'paged' => absint($paged),
				'max_num_pages' => absint($max_num_pages),
				'next_posts' => next_posts(absint($max_num_pages), false),
				'show_more' => __('Load More', 'fort-masonry'),
				'no_more_posts' => __('No More', 'fort-masonry'),
				'pagination_option' => $fort_pagination_option
			));
        }
    }
}
add_action('wp_enqueue_scripts', 'fort_grid_scripts');


/**
 * Fort Theme Customizer default values
 *
 * @package Fort
 */
if (!function_exists('fort_default_theme_options_values')) :
    function fort_default_theme_options_values()
    {
        $default_theme_options = array(
            /*Top Header*/
            'fort-make-logo-center' => true,
            'fort-enable-top-header' => false,
            'fort-enable-top-header-social' => true,
            'fort-enable-top-header-menu' => true,
            'fort-enable-top-header-search' => true,
            'fort-enable-top-header-notification' => esc_html__('Subscribe to Us', 'fort-masonry'),
            'fort-enable-top-header-notification-url' => '#',
            'fort-enable-top-header-notification-icon' => esc_html__('fa-bell', 'fort-masonry'),
            'fort-top-header-background-color' => '#eee',
            'fort-enable-headr-advertisement' => true,
            'fort-header-ads-image-file' => '',
            'fort-header-ads-image-url' => '#',

            /*Slider Settings Option*/
            'fort-enable-slider' => false,
            'fort-select-category' => 0,
            'fort-image-size-slider' => 'cropped-image',

            /*Category Boxes*/
            'fort-enable-category-boxes' => true,
            'fort-single-cat-posts-select-1' => 0,


            /*Sidebar Options*/
            'fort-sidebar-blog-page' => 'no-sidebar',
            'fort-sidebar-single-page' => 'right-sidebar',
            'fort-enable-sticky-sidebar' => true,


            /*Blog Page Default Value*/
            'fort-column-blog-page' => 'one-column',
            'fort-content-show-from' => 'excerpt',
            'fort-excerpt-length' => 25,
            'fort-pagination-options' => 'ajax',
            'fort-read-more-text' => esc_html__('Read More', 'fort-masonry'),
            'fort-blog-page-masonry-normal' => 'masonry',
            'fort-blog-page-image-position' => 'left-image',
            'fort-image-size-blog-page' => 'original-image',

            /*Blog Layout Overlay*/
            'fort-site-layout-blog-overlay' => 1,

            /*Single Page Default Value*/
            'fort-single-page-featured-image' => true,
            'fort-single-page-tags' => false,
            'fort-enable-underline-link' => true,
            'fort-single-page-related-posts' => true,
            'fort-single-page-related-posts-title' => esc_html__('Related Posts', 'fort-masonry'),


            /*Breadcrumb Settings*/
            'fort-blog-site-breadcrumb' => true,
            'fort-breadcrumb-display-from-option' => 'theme-default',
            'fort-breadcrumb-text' => '',

            /*General Colors*/
            'fort-primary-color' => '#1b1b1b',
            'fort-header-description-color' => '#404040',

            'fort-overlay-color' => 'rgba(209, 0, 20, 0.5)',
            'fort-overlay-second-color' => 'rgba(0, 0, 0, 0.5)',

            /*Footer Options*/
            'fort-footer-copyright' => esc_html__('All Rights Reserved 2022.', 'fort-masonry'),
            'fort-go-to-top' => true,
            'fort-go-to-top-icon' => esc_html__('fa-chevron-up', 'fort-masonry'),
            'fort-go-to-top-icon-5' => esc_html__('fa-chevron-up', 'fort-masonry'),
            'fort-footer-social-icons' => true,
            'fort-footer-mailchimp-subscribe' => true,
            'fort-footer-mailchimp-form-id' => '',
            'fort-footer-mailchimp-form-title' =>  esc_html__('Subscribe to my Newsletter', 'fort-masonry'),
            'fort-footer-mailchimp-form-subtitle' => esc_html__('Be the first to receive the latest buzz on upcoming contests & more!', 'fort-masonry'),

            /*Font Options*/
            'fort-font-family-url' => 'Open+Sans+Condensed:300,300italic,700',
            'fort-font-heading-family-url' => 'Domine:400,500,600,700',

            /*Extra Options*/
            'fort-post-published-updated-date' => 'post-published',
            'fort-font-awesome-version-loading' => 'version-4',

        );
        return apply_filters('fort_default_theme_options_values', $default_theme_options);
    }
endif;

/* Word read count Pagination */
if (!function_exists('fort_grid_read_time')) :
    /**
     * @param $content
     *
     * @return string
     */
    function fort_grid_read_time($post_id)
    {
        $content = apply_filters('the_content', get_post_field('post_content', $post_id));
        $read_words = 200;
        $decode_content = html_entity_decode($content);
        $filter_shortcode = do_shortcode($decode_content);
        $strip_tags = wp_strip_all_tags($filter_shortcode, true);
        $count = str_word_count($strip_tags);
        $word_per_min = (absint($count) / $read_words);
        $word_per_min = ceil($word_per_min);
        if (absint($word_per_min) > 0) {
            $word_count_strings = sprintf(_n('%s min read', '%s min read', number_format_i18n($word_per_min), 'fort-masonry'), number_format_i18n($word_per_min));
            if ('post' == get_post_type($post_id)):
                echo '<span class="min-read">';
                echo esc_html($word_count_strings);
                echo '</span>';
            endif;
        }
    }
endif;


if (!function_exists('fort_posts_navigation')) {
    /**
     * Display pagination based on type seclected
     *
     * @since 1.0.0
     *
     */
    function fort_posts_navigation()
    {
        global $fort_theme_options;
        if ($fort_theme_options['fort-pagination-options'] == 'numeric') {
            the_posts_pagination();
        } elseif (($fort_theme_options['fort-pagination-options'] == 'ajax') ) {
            $page_number = get_query_var('paged');
            if ($page_number == 0) {
                $output_page = 2;
            } else {
                $output_page = $page_number + 1;
            }
            if (paginate_links()) {
                echo "<div class='ajax-pagination text-center'><div class='show-more' data-number='$output_page'><i class='fa fa-refresh'></i>" . __('Load More', 'fort-masonry') . "</div><div id='free-temp-post'></div></div>";
            }
        } else {
            the_posts_navigation();
        }

    }
}
add_action('fort_action_navigation', 'fort_posts_navigation', 10);


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fort_grid_customize_register( $wp_customize ) {

    $default = fort_default_theme_options_values();

/*Blog Page Pagination Options*/
$wp_customize->add_setting( 'fort_options[fort-pagination-options]', array(
    'capability'        => 'edit_theme_options',
    'transport' => 'refresh',
    'default'           => $default['fort-pagination-options'],
    'sanitize_callback' => 'fort_sanitize_select'
) );
$wp_customize->add_control( 'fort_options[fort-pagination-options]', array(
   'choices' => array(
    'default'    => __('Default','fort-masonry'),
    'numeric'    => __('Numeric','fort-masonry'),
    'ajax'    => __('Load More','fort-masonry'),
),
   'label'     => __( 'Pagination Types', 'fort-masonry' ),
   'description' => __('Select the Required Pagination Type', 'fort-masonry'),
   'section'   => 'fort_blog_page_section',
   'settings'  => 'fort_options[fort-pagination-options]',
   'type'      => 'select',
   'priority'  => 10,
) );
}
add_action( 'customize_register', 'fort_grid_customize_register', 999 );